--[[---------------------------------------------------------------------------------
  MyACEPercentage - Originally by Instant.  Upgraded to Ace3 (ManaPerc) by phyber
------------------------------------------------------------------------------------]]
local ManaPerc = LibStub("AceAddon-3.0"):NewAddon("ManaPerc", "AceHook-3.0", "AceConsole-3.0")
-- Default options
local defaults = {
	profile = {
		current = false,
		total = true,
		colour = true,
	},
}
-- Locale
local L = LibStub("AceLocale-3.0"):GetLocale("ManaPerc")
-- Some local functions
local string_find = string.find
local string_format = string.format
local string_gsub = string.gsub
local tonumber = tonumber
local UnitMana = UnitMana
local UnitManaMax = UnitManaMax
-- Our SV DB, we'll fill this in later
local db

-- Return our options table
local function getOptions()
	local options = {
		type = "group",
		name = L["ManaPerc"],
		args = {
			mpdesc = {
				type = "description",
				order = 0,
				name = L["Shows mana usage as a percentage in a spells tooltip."],
			},
			total = {
				name = L["Show Total"],
				desc = L["TOTAL_DESC"],
				type = "toggle",
				order = 2,
				width = "full",
				get = function() return db.total end,
				set = function() db.total = not db.total end,
			},
			current = {
				name = L["Show Current"],
				desc = L["CURRENT_DESC"],
				type = "toggle",
				order = 3,
				width = "full",
				get = function() return db.current end,
				set = function() db.current = not db.current end,
			},
			colour = {
				name = L["Enable Colour"],
				desc = L["COLOUR_DESC"],
				type = "toggle",
				order = 1,
				width = "full",
				get = function() return db.colour end,
				set = function() db.colour = not db.colour end,
			}
		}
	}
	return options
end

--[[--------------------------------------------------------------------------------
  Addon Enabling/Disabling
-----------------------------------------------------------------------------------]]
function ManaPerc:OnInitialize()
	-- Grab our DB and fill in the 'db' variable
	self.db = LibStub("AceDB-3.0"):New("ManaPercDB", defaults, "Default")
	db = self.db.profile
	-- Register our options
	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("ManaPerc", getOptions)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("ManaPerc", L["ManaPerc"])
	-- Register chat command to open the options dialog
	self:RegisterChatCommand("manaperc", function() InterfaceOptionsFrame_OpenToFrame(LibStub("AceConfigDialog-3.0").BlizOptions["ManaPerc"].frame) end)
end

function ManaPerc:OnEnable()
	self:HookScript(GameTooltip, "OnTooltipSetSpell", "ProcessOnShow")
end
--[[--------------------------------------------------------------------------------
  Main Processing
-----------------------------------------------------------------------------------]]
function ManaPerc:ProcessOnShow(...)
	local tipline2 = GameTooltipTextLeft2:GetText()
	if tipline2 and string_find(tipline2, MANA_COST) then
		local dttext, dctext = "", ""
		local line2cost = string_gsub(tipline2, string_gsub(MANA_COST, "%%d", ""), "")
		line2cost = tonumber(line2cost)
		--
		if db.total and line2cost then
			local ttext = string_format("%.1f", line2cost / (UnitManaMax('player') / 100))
			if db.colour then
				dttext = " |cFFFFFF00("..ttext.."%)"			
			else
				dttext = " (t:"..ttext.."%)"
			end
		end
		--
		if db.current and line2cost then
			local ctext = string_format ("%.1f", line2cost / (UnitMana('player') / 100))
			if db.colour then
				dctext = " |cFF00FF00("..ctext.."%)"
			else
				dctext = " (c:"..ctext.."%)"
			end
		end
		GameTooltipTextLeft2:SetText(string_format(MANA_COST, line2cost)..dctext..dttext)
	end
	-- Call the original function
	self.hooks[GameTooltip]["OnTooltipSetSpell"](...)
end
